@@ -2,21 +2,30 @@
 #
 
 # Copyright (C) 2006, 2007, 2010, 2011, 2012, 2013 Google Inc.
+# All rights reserved.
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are
+# met:
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
+# 1. Redistributions of source code must retain the above copyright notice,
+# this list of conditions and the following disclaimer.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# 2. Redistributions in binary form must reproduce the above copyright
+# notice, this list of conditions and the following disclaimer in the
+# documentation and/or other materials provided with the distribution.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
+# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
+# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 """Cluster related commands"""
 
@@ -30,6 +39,7 @@ from cStringIO import StringIO
 import os
 import time
 import OpenSSL
+import tempfile
 import itertools
 
 from ganeti.cli import *
@@ -1862,6 +1872,10 @@ def _UpgradeBeforeConfigurationChange(versionstring):
     ToStderr("Failed to completely empty the queue.")
     return (False, rollback)
 
+  ToStdout("Pausing the watcher for one hour.")
+  rollback.append(lambda: GetClient().SetWatcherPause(None))
+  GetClient().SetWatcherPause(time.time() + 60 * 60)
+
   ToStdout("Stopping daemons on master node.")
   if not _RunCommandAndReport([pathutils.DAEMON_UTIL, "stop-all"]):
     return (False, rollback)
@@ -1877,13 +1891,20 @@ def _UpgradeBeforeConfigurationChange(versionstring):
     ToStderr("Failed to stop daemons on %s." % (", ".join(badnodes),))
     return (False, rollback)
 
-  backuptar = os.path.join(pathutils.LOCALSTATEDIR,
-                           "lib/ganeti%d.tar" % time.time())
+  backuptar = os.path.join(pathutils.BACKUP_DIR, "ganeti%d.tar" % time.time())
   ToStdout("Backing up configuration as %s" % backuptar)
-  if not _RunCommandAndReport(["tar", "cf", backuptar,
+  if not _RunCommandAndReport(["mkdir", "-p", pathutils.BACKUP_DIR]):
+    return (False, rollback)
+
+  # Create the archive in a safe manner, as it contains sensitive
+  # information.
+  (_, tmp_name) = tempfile.mkstemp(prefix=backuptar, dir=pathutils.BACKUP_DIR)
+  if not _RunCommandAndReport(["tar", "-cf", tmp_name,
+                               "--exclude=queue/archive",
                                pathutils.DATA_DIR]):
     return (False, rollback)
 
+  os.rename(tmp_name, backuptar)
   return (True, rollback)
 
 
@@ -2023,6 +2044,10 @@ def _UpgradeAfterConfigurationChange(oldversion):
   if not _RunCommandAndReport([pathutils.POST_UPGRADE, oldversion]):
     returnvalue = 1
 
+  ToStdout("Unpasuing the watcher.")
+  if not _RunCommandAndReport(["gnt-cluster", "watcher", "continue"]):
+    returnvalue = 1
+
   ToStdout("Verifying cluster.")
   if not _RunCommandAndReport(["gnt-cluster", "verify"]):
     returnvalue = 1
@@ -2046,6 +2071,22 @@ def UpgradeGanetiCommand(opts, args):
              " has to be given")
     return 1
 
+  # If we're not told to resume, verify there is no upgrade
+  # in progress.
+  if not opts.resume:
+    oldversion, versionstring = _ReadIntentToUpgrade()
+    if versionstring is not None:
+      # An upgrade is going on; verify whether the target matches
+      if versionstring == opts.to:
+        ToStderr("An upgrade is already in progress. Target version matches,"
+                 " resuming.")
+        opts.resume = True
+        opts.to = None
+      else:
+        ToStderr("An upgrade from %s to %s is in progress; use --resume to"
+                 " finish it first" % (oldversion, versionstring))
+        return 1
+
   oldversion = constants.RELEASE_VERSION
 
   if opts.resume:
