@@ -2,21 +2,30 @@
 #
 
 # Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012 Google Inc.
+# All rights reserved.
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are
+# met:
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
+# 1. Redistributions of source code must retain the above copyright notice,
+# this list of conditions and the following disclaimer.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# 2. Redistributions in binary form must reproduce the above copyright
+# notice, this list of conditions and the following disclaimer in the
+# documentation and/or other materials provided with the distribution.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
+# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
+# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 """Xen hypervisors
@@ -169,20 +178,32 @@ def _GetAllInstanceList(fn, include_node, _timeout=5):
   return _ParseInstanceList(lines, include_node)
 
 
-# Determine whether an instance is running
-#
-# An instance is running if it is in the following Xen states:
-# running, blocked, or paused.
-#
-# For some strange reason, Xen once printed 'rb----' which does not
-# make any sense because an instance cannot be both running and
-# blocked.  Fortunately, for Ganeti 'running' or 'blocked' is the same
-# as 'running'.
 def _IsInstanceRunning(instance_info):
+  """Determine whether an instance is running.
+
+  An instance is running if it is in the following Xen states:
+  running, blocked, or paused.
+
+  For some strange reason, Xen once printed 'rb----' which does not make any
+  sense because an instance cannot be both running and blocked.  Fortunately,
+  for Ganeti 'running' or 'blocked' is the same as 'running'.
+
+  A state of nothing '------' means that the domain is runnable but it is not
+  currently running.  That means it is in the queue behind other domains waiting
+  to be scheduled to run.
+  http://old-list-archives.xenproject.org/xen-users/2007-06/msg00849.html
+
+  @type instance_info: string
+  @param instance_info: Information about instance, as supplied by Xen.
+  @rtype: bool
+  @return: Whether an instance is running.
+
+  """
   return instance_info == "r-----" \
-      or instance_info == "-b----" \
       or instance_info == "rb----" \
-      or instance_info == "--p---"
+      or instance_info == "-b----" \
+      or instance_info == "--p---" \
+      or instance_info == "------"
 
 
 def _IsInstanceShutdown(instance_info):
